Learn R Programming

trialr (version 0.1.3)

dose_finding_fit-class: Class of dose-finding model fit by trialr using Stan.

Description

Class of dose-finding model fit by trialr using Stan.

Usage

dose_finding_fit(dose_indices, num_patients, doses, tox, prob_tox,
  median_prob_tox, recommended_dose, dat, fit)

Arguments

dose_indices

A vector of integers representing the dose-levels under consideration.

num_patients

Integer, the number of patients analysed.

doses

vector of integers representing the dose given to the patients.

tox

vector of integers representing the toxicity status of the patients.

prob_tox

The posterior mean probabilities of toxicity at doses 1:n; a vector of numbers between 0 and 1.

median_prob_tox

The posterior median probabilities of toxicity at doses 1:n; a vector of numbers between 0 and 1.

recommended_dose

An integer representing the dose-level that is recommended for the next patient or cohort.

dat

Object crm_params containing data passed to sampling.

fit

An object of class stanfit, containing the posterior samples.

See Also

crm_fit, efftox_fit