Learn R Programming

trialr (version 0.1.3)

predict.augbin_2t_1a_fit: Predict probability of success for given tumour size measurements.

Description

This method simply forwards to prob_success.

Usage

# S3 method for augbin_2t_1a_fit
predict(object, y1_lower = -Inf,
  y1_upper = Inf, y2_lower = -Inf, y2_upper = log(0.7),
  probs = c(0.025, 0.975), newdata = NULL, ...)

Arguments

object

Object of class augbin_2t_1a_fit.

y1_lower

numeric, minimum threshold to constitute success, scrutinising the log of the tumour size ratio comparing time 1 to baseline. Defaults to negative infinity.

y1_upper

numeric, maximum threshold to constitute success, scrutinising the log of the tumour size ratio comparing time 1 to baseline. Defaults to positive infinity.

y2_lower

numeric, minimum threshold to constitute success, scrutinising the log of the tumour size ratio comparing time 2 to baseline.

y2_upper

numeric, maximum threshold to constitute success, scrutinising the log of the tumour size ratio comparing time 2 to baseline. Defaults to log(0.7).

probs

pair of probabilities to use to calculate the credible interval for the probability of success.

newdata

data for which to infer the probability of success. A dataframe-like object with baseline tumour sizes in first column, and first and second post-baseline tumour sizes in columns 2 and 3. Omitted by default. When omitted, newdata is set to be the object$tumour_size.

...

Extra args passed onwards.

Value

Object of class tibble