powered by
Calculate the codified CRM doses that map to probability of toxicity prob_tox in a logistic model with expected values for intercept and gradient. I.e. find \(x[i]\) such that \(logit(p[i]) = \alpha + \beta x[i]\), were \(p\) is prob_tox.
prob_tox
crm_codified_dose_logistic(prob_tox, alpha_mean, beta_mean)
Numeric vector, seek codified doses that yield these probabilities of toxicity.
Numeric, expected value of intercept.
Numeric, expected value of gradient with respect to dose.
Numeric vector of codified doses.
# NOT RUN { skeleton <- c(0.05, 0.1, 0.2, 0.5) crm_codified_dose_logistic(skeleton, 1, 0) crm_codified_dose_logistic(skeleton, 3, 0.5) # }
Run the code above in your browser using DataLab