Learn R Programming

trialr (version 0.1.3)

efftox_superiority: Get dose-superiority matrix in EffTox

Description

Get a dose-superiority matrix from an EffTox dose analysis. EffTox seeks to choose the dose with the highest utility, thus superiority is inferred by posterior utility. The item in row i, col j is the posterior probability that the utility of dose j exceeds that of dose i.

Usage

efftox_superiority(fit)

Arguments

fit

An instance of efftox_fit.

Value

n by n matrix, where n is number of doses under investigation. The item in row i, col j is the posterior probability that the utility of dose j exceeds that of dose i.

Examples

Run this code
# NOT RUN {
fit <- stan_efftox_demo('1N 2E 3B')
sup_mat <- efftox_superiority(fit)
# }

Run the code above in your browser using DataLab