This method simply forwards to prob_success.
# S3 method for augbin_2t_1a_fit
predict(object, y1_lower = -Inf,
y1_upper = Inf, y2_lower = -Inf, y2_upper = log(0.7),
probs = c(0.025, 0.975), newdata = NULL, ...)Object of class augbin_2t_1a_fit.
numeric, minimum threshold to constitute success, scrutinising the log of the tumour size ratio comparing time 1 to baseline. Defaults to negative infinity.
numeric, maximum threshold to constitute success, scrutinising the log of the tumour size ratio comparing time 1 to baseline. Defaults to positive infinity.
numeric, minimum threshold to constitute success, scrutinising the log of the tumour size ratio comparing time 2 to baseline.
numeric, maximum threshold to constitute success, scrutinising the log of the tumour size ratio comparing time 2 to baseline. Defaults to log(0.7).
pair of probabilities to use to calculate the credible interval for the probability of success.
data for which to infer the probability of success.
A dataframe-like object with baseline tumour sizes in first column, and first
and second post-baseline tumour sizes in columns 2 and 3. Omitted by default.
When omitted, newdata is set to be the object$tumour_size.
Extra args passed onwards.
Object of class tibble